summaryrefslogtreecommitdiffstats
path: root/libkdepim/sidebarextension.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/sidebarextension.h')
-rw-r--r--libkdepim/sidebarextension.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/libkdepim/sidebarextension.h b/libkdepim/sidebarextension.h
index 3a7ffbe5..98b185c1 100644
--- a/libkdepim/sidebarextension.h
+++ b/libkdepim/sidebarextension.h
@@ -35,9 +35,10 @@ namespace KParts
* Provides a way to export a widget which will be displayed in Kontacts
* stackview at the left
**/
- class KDE_EXPORT SideBarExtension : public QObject
+ class KDE_EXPORT SideBarExtension : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
@@ -45,10 +46,10 @@ namespace KParts
*
* @param exported A TQWidget derived widget that will be provided for the
* users of SideBarExtension.
* @param parent The parent widget.
* @param name The name of the class.
**/
- SideBarExtension(TQWidget *exported, KParts::ReadOnlyPart *parent, const char* name);
+ SideBarExtension(TQWidget *exported, KParts::ReadOnlyPart *tqparent, const char* name);
~SideBarExtension();
/**
@@ -45,10 +46,10 @@ namespace KParts
* @param exported A TQWidget derived widget that will be provided for the
* users of SideBarExtension.
- * @param parent The parent widget.
+ * @param tqparent The tqparent widget.
* @param name The name of the class.
**/